# Makefile for all IBM huffman variants
# Needed:
# Borland's make utility
# Borland Pascal 7.0 or higher

# Optional:
# (Not necessary for compilation)
# ScanHelp by D.J. Murdoch only necessary if you plan to better comment src.
# Words conversion utility by Joe Jared

.silent

#Huffman conditionals for this version

#JARED	=JARED 		# Never implement!!!
NVAL = 1000			# size of string buffer
FVAL = 60			# size of look-ahead buffer

LVERMAJOR  = 0		# Major portion of Version
LVERMINOR  = 29		# Minor portion of Version


#DEBUGMODE = 1		# For debugmode operations.
PROTMODE = 1		# for Dos protected mode implementation

# Turbo Pascal directories
HOME	= e:\tp
TPEXE	= $(HOME)\bin
OBJ		= $(HOME)\obj
UNITS	= $(HOME)\units
PASINC	= $(HOME)\INCLUDE
SRC		= $(HOME)\lzh

!if $d(PROTMODE)
PTYPE = P
TPUEXT = .TPP
!else
PTYPE = D
TPUEXT = .TPU
!endif

	!if $d(DEBUGMODE)
PASFLAGS = -C$(PTYPE) -$a+,b-,D+,e-,f-,G+,l+,O+,q+,r+,s+,t-,v-,x+,y+ /V -O$(OBJ) -I$(PASINC) -U$(UNITS)

	!else
PASFLAGS = -C$(PTYPE) -$a+,b-,D-,e-,f-,G+,l-,O+,q-,r-,s-,t-,v-,x+,y- -O$(OBJ) -I$(PASINC) -U$(UNITS)
	!endif


#
.SUFFIXES: .tph .obj .asm $(TPUEXT) .pas

.asm.obj:
	ml /c /Cu /W3 /Sn /nologo /Fo$*.obj $*.asm

.pas$(TPUEXT):
	$(TPEXE)\bpc $* $(PASFLAGS)


.pas.exe:
	bpc $* $(PASFLAGS)

$(TPUEXT).tph:
	-scanhelp /O$@ $*.pas /U $(UNITS) /I $(PASINC)



#
Targets: lz.exe testlzo.exe $(UNITS)\lzo.tph
	!if $d(JARED)
	!endif

lz.exe: $(UNITS)\lzh$(TPUEXT)

testlzo.exe: $(UNITS)\lzo$(TPUEXT)

$(UNITS)\lzo$(TPUEXT): $(UNITS)\lzh$(TPUEXT)


#
#Dependencies

$(UNITS)\lzh$(TPUEXT): $(PASINC)\lzh.inc $(OBJ)\lzhasm.obj

$(PASINC)\lzh.inc: makefile.mak
	copy &&!
const
	{ This file created by Borland's MAKE utility }
	EngineVer = '$(LVERMAJOR).$(LVERMINOR)';
	{ Version of Huffman compression engine}
	{ Note: Actual include file is generated by borland's Make utility}
	N	  = $$(NVAL) ; {Size of string buffer}
	F	  = $(FVAL)	    ; {60 Size of look-ahead buffer}
	{These constants are hard coded into LZHASM.OBJ}
! $@

#
	!if $d(JARED)
release: $(SRC)\tplzh$(LVERMAJOR)$(LVERMINOR).zip

$(SRC)\tplzh$(LVERMAJOR)$(LVERMINOR).zip: makefile.mak file_id.diz\
	$(UNITS)\lzh.pas lz.pas $(OBJ)\lzhasm.obj $(UNITS)\lzo.pas\
	testlzo.pas	$(PASINC)\lzh.inc tplzh.hst TPLZH.DOC\
	$(UNITS)\lzo.tph lzhasm.inc
	words &&!
 $?
! release.lst
	!if $d(DEBUGMODE)
		echo release failed DEBUGMODE defined in makefile
	!else
	pkzip -ex -a -P $@ @$(SRC)\release.lst
	!endif

	!endif
file_id.diz: makefile.mak
	copy &&!
Huffman Compression Engine v$(LVERMAJOR).$(LVERMINOR) IBM Version
By:  Joe Jared,1:103/400.1@Fidonet.Org and others
Aka: JoeJared@webworldinc.com
Atari ST/TT/JAGUAR & SNES available.
UPDATES: DPMI mode now supported Borland help files included with this release.
! $@

# This section should only be enabled if you have lzhasm.asm
!if $d(JARED)
$(OBJ)\lzhasm.obj: LZHASM.inc

LZHASM.inc: makefile.mak
	copy &&!
;	 This file created by Borland's MAKE utility
; This file is not needed by end users but shows how you can
; use make to create interface files between languages.

threshold  	equ 2	       ;  {define from pwb or /dthreshold=
n			equ $(NVAL)h	      ; {size of string buffer}
f			equ $(FVAL)		     ; {size of look-ahead buffer}

! $@
!endif


$(UNITS)\lzo.tph: $(UNITS)\lzh$(TPUEXT)